==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/zh/api.php <==
<?php
regGS("The IP address group $1 has been deleted.", "");
regGS("IP Group $1 added for user $2", "");
regGS("User permissions for $1 changed", "");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "");
regGS("Issue $1 changed status to $2", "");
regGS("User type $1 deleted", "");
regGS("User type $1 added", "");
regGS("Topic $1 added to article", "主题$1已添加到文章中");
regGS("Last", "");
regGS("First", "");
regGS("Changed image properties of $1", "已变化$1的图片属性");
regGS("Article topic $1 deleted", "文章主题已删除");
regGS("Article #$1 \"$2\" ($3) created.", "");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "");
regGS("Article #$1: \"$2\" ($3) deleted.", "");
regGS("Text", "");
regGS("Article body", "");
regGS("The default subscription time for $1 has been added.", "增加新国家的默认订阅时间");
regGS("The image $1 has been added.", "图片$1已被添加");
regGS("Image $1 deleted", "图片$1已删除");
regGS("Publication $1 changed", "出版物$1已改变");
regGS("Publication $1 deleted", "出版物$1已被删除");
regGS("Publication $1 added", "出版物$1已添加");
regGS("Issue $1 from publication $2 deleted", "来自发布$2的议题$1已删除");
regGS("Issue $1 added in publication $2", "议题$1被加入发布$2");
regGS("The article type $1 has been deleted.", "文章类型$1已被删除");
regGS("The article type $1 has been added.", "文章类型$1已被添加");
regGS("Article type field $1 created", "文章类型字段$1已建立");
regGS("Article type field $1 deleted", "文章类型字段$1已删除");
regGS("Language $1 added", "语言$1被添加");
regGS("Language $1 deleted", "语言$1已删除");
regGS("Language $1 modified", "语言$1已修改");
regGS("Country $1 added", "国家$1已增加");
regGS("Country $1 deleted", "国家$1被删除");
regGS("Country name $1 changed", "国家名称$1被改变");
regGS("The user account $1 has been deleted.", "帐户$1已被删除");
regGS("Password changed for $1", "$1的密码已改变");
regGS("User account $1 created", "帐户$1已产生");
regGS("Template $1 uploaded", "模版$1已上载");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/zh/api.php <==
<?php 
regGS("Template $1 no longer exists!", "");
regGS("The file uploaded is not an image.", "");
regGS("Field $1 updated", "");
regGS("Could not delete record from the database.", "");
regGS("template path", "");
regGS("short names", "");
regGS("Unable to fetch image from remote server.", "");
regGS("The article type field $1 has been renamed to $2.", "");
regGS("The article type $1 has been renamed to $2.", "");
regGS("Article type field $1 changed", "");
regGS("Article Type $1 translation updated", "");
regGS("The IP address group $1 has been deleted.", "");
regGS("IP Group $1 added for user $2", "");
regGS("User permissions for $1 changed", "");
regGS("Section $1 deleted. (Issue: $2, Publication: $3)", "");
regGS("Section $1 added. (Issue: $2, Publication: $3)", "");
regGS("Issue $1 changed status to $2", "");
regGS("User type $1 deleted", "");
regGS("User type $1 added", "");
regGS("Topic $1 added to article", "主题$1已添加到文章中");
regGS("Last", "");
regGS("First", "");
regGS("Changed image properties of $1", "已变化$1的图片属性");
regGS("Article topic $1 deleted", "文章主题已删除");
regGS("Article #$1 \"$2\" ($3) created.", "");
regGS("Article #$1 \"$2\" ($3) translated to \"$5\" ($4)", "");
regGS("Article #$1 \"$2\" ($3) copied to Article #$3. ", "");
regGS("Article #$1: \"$2\" status changed from $3 to $4.", "");
regGS("Article #$1: \"$2\" ($3) deleted.", "");
regGS("Single-line Text", "");
regGS("Multi-line Text with WYSIWYG", "");
regGS("The default subscription time for $1 has been added.", "增加新国家的默认订阅时间");
regGS("Image $1 linked to article $2", "");
regGS("Image $1 unlinked from $2", "");
regGS("The image $1 has been added.", "图片$1已被添加");
regGS("Image $1 deleted", "图片$1已删除");
regGS("Publication $1 changed", "出版物$1已改变");
regGS("Publication $1 deleted", "出版物$1已被删除");
regGS("Publication $1 added", "出版物$1已添加");
regGS("Issue $1 from publication $2 deleted", "来自发布$2的议题$1已删除");
regGS("Issue $1 added in publication $2", "议题$1被加入发布$2");
regGS("The article type $1 has been deleted.", "文章类型$1已被删除");
regGS("The article type $1 has been added.", "文章类型$1已被添加");
regGS("Article type field $1 created", "文章类型字段$1已建立");
regGS("Article type field $1 deleted", "文章类型字段$1已删除");
regGS("Language $1 added", "语言$1被添加");
regGS("Language $1 deleted", "语言$1已删除");
regGS("Language $1 modified", "语言$1已修改");
regGS("Country $1 added", "国家$1已增加");
regGS("Country $1 deleted", "国家$1被删除");
regGS("Country name $1 changed", "国家名称$1被改变");
regGS("The user account $1 has been deleted.", "帐户$1已被删除");
regGS("Password changed for $1", "$1的密码已改变");
regGS("User account $1 created", "帐户$1已产生");
regGS("Template $1 uploaded", "模版$1已上载");
regGS("URL \"$1\" is invalid or is not an image.", "");
regGS("URL \"$1\" is not an image.", "");
regGS("Topic $1 added", "主题$1已添加");
regGS("Topic $1 deleted", "主题$1已删除");
regGS("Topic $1 updated", "主题$1已更新");
?>
